window.Gleam.initSearch([{"doc":"gleamyshell","title":"gleamyshell","content":"# GleamyShell\n\nGleamyShell is a cross-platform Gleam library for executing shell commands that supports multiple targets (Erlang, Deno,\nand Node.js).\n\n## When to use GleamyShell?\n\nGleamyShell provides the ability to execute shell commands on multiple targets. While this might sound amazing,\nsupporting targets with fundamentally different concurrency models shrinks the common ground significantly.\n\nIn order to keep the public API homogenous across different targets, GleamyShell only provides synchronous bindings.\n\nYou should use GleamyShell if\n\n-   you need or want to support multiple targets _and/or_\n-   synchronous shell command execution is not a concern.\n\n## Usage\n\n### Getting the current username\n\n```gleam\nlet result = gleamyshell.execute(&quot;whoami&quot;, [])\n\ncase result {\n  Ok(username) -&gt;\n    io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n  Error(Failure(output, exit_code)) -&gt;\n    io.println(\n      &quot;Whoops!\\nError (&quot;\n      &lt;&gt; int.to_string(exit_code)\n      &lt;&gt; &quot;): &quot;\n      &lt;&gt; string.trim(output),\n    )\n  Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n}\n```\n\n### Getting the current working directory\n\n```gleam\ncase gleamyshell.cwd() {\n  Some(working_directory) -&gt;\n    io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n  None -&gt;\n    io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n}\n```\n\n## Changelog\n\nTake a look at the [changelog](https://github.com/patrik-kuehl/gleamyshell/blob/main/CHANGELOG.md) to get an overview of\neach release and its changes.\n\n## Contribution Guidelines\n\nMore information can be found [here](https://github.com/patrik-kuehl/gleamyshell/blob/main/CONTRIBUTING.md).\n\n## License\n\nGleamyShell is licensed under the [MIT license](https://github.com/patrik-kuehl/gleamyshell/blob/main/LICENSE.md).\n","url":"index.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThis project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## 0.1.0 - 2024-05-26\n\n### Features\n\n-   Implement execute_in function\n-   Introduce working directory parameter in execute FFI functions\n-   Handle abort reasons\n-   Implement Gleam cwd function\n-   Implement Elixir cwd function\n-   Implement JavaScript cwd function\n-   Implement Gleam execute function\n-   Implement Elixir execute function\n-   Implement JavaScript execute function\n\n&lt;!-- generated by git-cliff --&gt;\n","url":"changelog.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# MIT License\n\nCopyright (c) 2024 Patrik Kühl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n","url":"license.html"},{"doc":"gleamyshell","title":"AbortReason","content":"pub type AbortReason {\n  Enomem\n  Eagain\n  Enametoolong\n  Emfile\n  Enfile\n  Eacces\n  Enoent\n  Other(String)\n}\n Represents the reason why the execution of a command was aborted.\n\n Most of these reasons are common POSIX errors.\nEnomem\n Not enough memory.\n\nEagain\n Resource temporarily unavailable.\n\nEnametoolong\n Too long file name.\n\nEmfile\n Too many open files.\n\nEnfile\n File table overflow.\n\nEacces\n Insufficient permissions.\n\nEnoent\n No such file or directory.\n\nOther(String)\n An error not represented by the other options.\n\nSynonyms:\ngleamyshell.AbortReason\ngleamyshell AbortReason","url":"gleamyshell.html#AbortReason"},{"doc":"gleamyshell","title":"CommandError","content":"pub type CommandError {\n  Failure(output: String, exit_code: Int)\n  Abort(reason: AbortReason)\n}\n Represents information about why a command execution failed.\nFailure(output: String, exit_code: Int)\n The command could be executed but returned a non-zero exit code.\n\nAbort(reason: AbortReason)\n The command did not execute and instead was aborted.\n\nSynonyms:\ngleamyshell.CommandError\ngleamyshell CommandError","url":"gleamyshell.html#CommandError"},{"doc":"gleamyshell","title":"cwd","content":"pub fn cwd() -&gt; Option(String)\n Returns the current working directory.\n \n This function returns an `Option` because it can fail on Unix-like systems in rare circumstances.\n \n ## Example\n \n \n case gleamyshell.cwd() {\n   Some(working_directory) -&gt; io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n   None -&gt; io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n }\n \nSynonyms:\ngleamyshell.cwd\ngleamyshell cwd","url":"gleamyshell.html#cwd"},{"doc":"gleamyshell","title":"execute","content":"pub fn execute(\n  command command: String,\n  args args: List(String),\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments.\n\n ## Example\n \n \n let result = gleamyshell.execute(&quot;whoami&quot;, [])\n \n case result {\n   Ok(username) -&gt; io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n   Error(Failure(output, exit_code)) -&gt; io.println(&quot;Whoops!\\nError (&quot; &lt;&gt; int.to_string(exit_code) &lt;&gt; &quot;): &quot; &lt;&gt; string.trim(output))\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result = gleamyshell.execute(&quot;ls&quot;, args: [&quot;-la&quot;])\n let another_result = gleamyshell.execute(command: &quot;ls&quot;, args: [&quot;-la&quot;])\n \nSynonyms:\ngleamyshell.execute\ngleamyshell execute","url":"gleamyshell.html#execute"},{"doc":"gleamyshell","title":"execute_in","content":"pub fn execute_in(\n  command command: String,\n  args args: List(String),\n  working_directory working_directory: String,\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments in a specified working directory.\n\n ## Example\n \n \n let result = gleamyshell.execute_in(&quot;cat&quot;, [&quot;.bashrc&quot;], &quot;/home/username&quot;)\n \n case result {\n   Ok(file_content) -&gt; io.println(file_content)\n   Error(Failure(output, exit_code)) -&gt; io.println(&quot;Whoops!\\nError (&quot; &lt;&gt; int.to_string(exit_code) &lt;&gt; &quot;): &quot; &lt;&gt; string.trim(output))\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result = gleamyshell.execute_in(&quot;ls&quot;, args: [&quot;-la&quot;], working_directory: &quot;/usr/bin&quot;)\n let another_result = gleamyshell.execute_in(command: &quot;ls&quot;, args: [&quot;-la&quot;], working_directory: &quot;/usr/bin&quot;)\n \nSynonyms:\ngleamyshell.execute_in\ngleamyshell execute_in","url":"gleamyshell.html#execute_in"},{"doc":"gleamyshell","title":"gleamyshell","content":"","url":"gleamyshell.html"}]);